traitsui\.editors\.styled\_date\_editor module
==============================================

.. automodule:: traitsui.editors.styled_date_editor
    :members:
    :undoc-members:
    :show-inheritance:
